package com.muyu.platform.controller;

import java.util.Arrays;
import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.platform.domain.WarnRule;
import com.muyu.platform.service.IWarnRuleService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.security.utils.SecurityUtils;
import org.springframework.validation.annotation.Validated;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 预警规则Controller
 *
 * @author muyu
 * @date 2024-09-20
 */
@RestController
@RequestMapping("/rule")
public class WarnRuleController extends BaseController
{
    @Resource
    private IWarnRuleService warnRuleService;

    /**
     * 查询预警规则列表
     */
    @RequiresPermissions("platform:rule:list")
    @GetMapping("/list")
    public Result<TableDataInfo<WarnRule>> list(WarnRule warnRule)
    {
        startPage();
        List<WarnRule> list = warnRuleService.selectWarnRuleList(warnRule);
        return getDataTable(list);
    }

    /**
     * 导出预警规则列表
     */
    @RequiresPermissions("platform:rule:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, WarnRule warnRule)
    {
        List<WarnRule> list = warnRuleService.selectWarnRuleList(warnRule);
        ExcelUtil<WarnRule> util = new ExcelUtil<WarnRule>(WarnRule.class);
        util.exportExcel(response, list, "预警规则数据");
    }

    /**
     * 获取预警规则详细信息
     */
    @RequiresPermissions("platform:rule:query")
    @GetMapping(value = "/{id}")
    public Result<List<WarnRule>> getInfo(@PathVariable("id") Long id)
    {
        return success(warnRuleService.selectWarnRuleById(id));
    }

    /**
     * 新增预警规则
     */
    @RequiresPermissions("platform:rule:add")
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody WarnRule warnRule)
    {
        if (warnRuleService.checkIdUnique(warnRule)) {
            return error("新增 预警规则 '" + warnRule + "'失败，预警规则已存在");
        }
        return toAjax(warnRuleService.save(warnRule));
    }

    /**
     * 修改预警规则
     */
    @RequiresPermissions("platform:rule:edit")
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody WarnRule warnRule)
    {
        if (!warnRuleService.checkIdUnique(warnRule)) {
            return error("修改 预警规则 '" + warnRule + "'失败，预警规则不存在");
        }
        return toAjax(warnRuleService.updateById(warnRule));
    }

    /**
     * 删除预警规则
     */
    @RequiresPermissions("platform:rule:remove")
	@DeleteMapping("/{ids}")
    public Result<Integer> remove(@PathVariable("ids") Long[] ids)
    {
        warnRuleService.removeBatchByIds(Arrays.asList(ids));
        return success();
    }
}
